Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Check ¶
Check inspects a SQL string and returns an error message if it uses a DSQL-unsupported feature, or "" if the statement is allowed.
Types ¶
type BypassConfig ¶
BypassConfig holds credentials for auth bypass mode. When set, the proxy accepts any client auth and connects to the backend using these credentials instead of relaying auth from the client.
type RunInput ¶
type RunInput struct {
ListenAddr string `validate:"required"`
UpstreamAddr string `validate:"required"`
}
RunInput holds the configuration for the proxy server.
Click to show internal directories.
Click to hide internal directories.